==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/math2/odelib/odlqnp.c <==
/* src/math2/odelib/odlqnp.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__3 = 3;
static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     LOGICAL PARAMETER CONTROL */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int odlqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
	logical *lpara, integer *in, ftnlen cp_len)
{
    /* Initialized data */

    static char cparas[8*1] = "LBAR    ";
    static logical lx[1] = { FALSE_ };
    static char cparal[40*1] = "LBAR                                    ";
    static logical lfirst = TRUE_;

    /* System generated locals */
    address a__1[3];
    integer i__1[3];

    /* Builtin functions */
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen),
	     s_copy(char *, char *, ftnlen, ftnlen);

    /* Local variables */
    static integer n, ix;
    extern integer lenc_(char *, ftnlen);
    static char cmsg[80];
    extern logical lchreq_(char *, char *, ftnlen, ftnlen);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), rllget_(char *, integer *, integer *, ftnlen), 
	    rtlget_(char *, char *, integer *, integer *, ftnlen, ftnlen);

    switch(n__) {
	case 1: goto L_odlqid;
	case 2: goto L_odlqcp;
	case 3: goto L_odlqcl;
	case 4: goto L_odlqvl;
	case 5: goto L_odlsvl;
	case 6: goto L_odlqin;
	}

    *ncp = 1;
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqid:
    for (n = 1; n <= 1; ++n) {
	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
	    *idx = n;
	    return 0;
	}
/* L10: */
    }
/* Writing concatenation */
    i__1[0] = 11, a__1[0] = "PARAMETER '";
    i__1[1] = lenc_(cp, cp_len), a__1[1] = cp;
    i__1[2] = 17, a__1[2] = "' IS NOT DEFINED.";
    s_cat(cmsg, a__1, i__1, &c__3, (ftnlen)80);
    msgdmp_("E", "ODLQID", cmsg, (ftnlen)1, (ftnlen)6, (ftnlen)80);
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqcp:
    if (1 <= *idx && *idx <= 1) {
	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
    } else {
	msgdmp_("E", "ODLQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqcl:
    if (1 <= *idx && *idx <= 1) {
	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
    } else {
	msgdmp_("E", "ODLQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqvl:
    if (lfirst) {
	rtlget_("OD", cparas, &ix, &c__1, (ftnlen)2, (ftnlen)8);
	rllget_(cparal, &ix, &c__1, (ftnlen)40);
	lfirst = FALSE_;
    }
    if (1 <= *idx && *idx <= 1) {
	*lpara = lx[*idx - 1];
    } else {
	msgdmp_("E", "ODLQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlsvl:
    if (lfirst) {
	rtlget_("OD", cparas, &ix, &c__1, (ftnlen)2, (ftnlen)8);
	rllget_(cparal, &ix, &c__1, (ftnlen)40);
	lfirst = FALSE_;
    }
    if (1 <= *idx && *idx <= 1) {
	lx[*idx - 1] = *lpara;
    } else {
	msgdmp_("E", "ODLSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqin:
    for (n = 1; n <= 1; ++n) {
	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
	    *in = n;
	    return 0;
	}
/* L20: */
    }
    *in = 0;
    return 0;
} /* odlqnp_ */

/* Subroutine */ int odlqnp_(integer *ncp)
{
    return odlqnp_0_(0, ncp, (char *)0, (integer *)0, (logical *)0, (integer *
	    )0, (ftnint)0);
    }

/* Subroutine */ int odlqid_(char *cp, integer *idx, ftnlen cp_len)
{
    return odlqnp_0_(1, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqcp_(integer *idx, char *cp, ftnlen cp_len)
{
    return odlqnp_0_(2, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqcl_(integer *idx, char *cp, ftnlen cp_len)
{
    return odlqnp_0_(3, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqvl_(integer *idx, logical *lpara)
{
    return odlqnp_0_(4, (integer *)0, (char *)0, idx, lpara, (integer *)0, (
	    ftnint)0);
    }

/* Subroutine */ int odlsvl_(integer *idx, logical *lpara)
{
    return odlqnp_0_(5, (integer *)0, (char *)0, idx, lpara, (integer *)0, (
	    ftnint)0);
    }

/* Subroutine */ int odlqin_(char *cp, integer *in, ftnlen cp_len)
{
    return odlqnp_0_(6, (integer *)0, cp, (integer *)0, (logical *)0, in, 
	    cp_len);
    }

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/math2/odelib/odlqnp.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__3 = 3;
static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     LOGICAL PARAMETER CONTROL */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int odlqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
	logical *lpara, integer *in, ftnlen cp_len)
{
    /* Initialized data */

    static char cparas[8*1] = "LBAR    ";
    static logical lx[1] = { FALSE_ };
    static char cparal[40*1] = "LBAR                                    ";
    static logical lfirst = TRUE_;

    /* System generated locals */
    address a__1[3];
    integer i__1[3];

    /* Builtin functions */
    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen),
	     s_copy(char *, char *, ftnlen, ftnlen);

    /* Local variables */
    static integer n, ix;
    extern integer lenc_(char *, ftnlen);
    static char cmsg[80];
    extern logical lchreq_(char *, char *, ftnlen, ftnlen);
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), rllget_(char *, integer *, integer *, ftnlen), 
	    rtlget_(char *, char *, integer *, integer *, ftnlen, ftnlen);

    switch(n__) {
	case 1: goto L_odlqid;
	case 2: goto L_odlqcp;
	case 3: goto L_odlqcl;
	case 4: goto L_odlqvl;
	case 5: goto L_odlsvl;
	case 6: goto L_odlqin;
	}

    *ncp = 1;
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqid:
    for (n = 1; n <= 1; ++n) {
	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
	    *idx = n;
	    return 0;
	}
/* L10: */
    }
/* Writing concatenation */
    i__1[0] = 11, a__1[0] = "PARAMETER '";
    i__1[1] = lenc_(cp, cp_len), a__1[1] = cp;
    i__1[2] = 17, a__1[2] = "' IS NOT DEFINED.";
    s_cat(cmsg, a__1, i__1, &c__3, (ftnlen)80);
    msgdmp_("E", "ODLQID", cmsg, (ftnlen)1, (ftnlen)6, (ftnlen)80);
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqcp:
    if (1 <= *idx && *idx <= 1) {
	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
    } else {
	msgdmp_("E", "ODLQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqcl:
    if (1 <= *idx && *idx <= 1) {
	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
    } else {
	msgdmp_("E", "ODLQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqvl:
    if (lfirst) {
	rtlget_("OD", cparas, &ix, &c__1, (ftnlen)2, (ftnlen)8);
	rllget_(cparal, &ix, &c__1, (ftnlen)40);
	lfirst = FALSE_;
    }
    if (1 <= *idx && *idx <= 1) {
	*lpara = lx[*idx - 1];
    } else {
	msgdmp_("E", "ODLQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlsvl:
    if (lfirst) {
	rtlget_("OD", cparas, &ix, &c__1, (ftnlen)2, (ftnlen)8);
	rllget_(cparal, &ix, &c__1, (ftnlen)40);
	lfirst = FALSE_;
    }
    if (1 <= *idx && *idx <= 1) {
	lx[*idx - 1] = *lpara;
    } else {
	msgdmp_("E", "ODLSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
		ftnlen)20);
    }
    return 0;
/* ----------------------------------------------------------------------- */

L_odlqin:
    for (n = 1; n <= 1; ++n) {
	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
	    *in = n;
	    return 0;
	}
/* L20: */
    }
    *in = 0;
    return 0;
} /* odlqnp_ */

/* Subroutine */ int odlqnp_(integer *ncp)
{
    return odlqnp_0_(0, ncp, (char *)0, (integer *)0, (logical *)0, (integer *
	    )0, (ftnint)0);
    }

/* Subroutine */ int odlqid_(char *cp, integer *idx, ftnlen cp_len)
{
    return odlqnp_0_(1, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqcp_(integer *idx, char *cp, ftnlen cp_len)
{
    return odlqnp_0_(2, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqcl_(integer *idx, char *cp, ftnlen cp_len)
{
    return odlqnp_0_(3, (integer *)0, cp, idx, (logical *)0, (integer *)0, 
	    cp_len);
    }

/* Subroutine */ int odlqvl_(integer *idx, logical *lpara)
{
    return odlqnp_0_(4, (integer *)0, (char *)0, idx, lpara, (integer *)0, (
	    ftnint)0);
    }

/* Subroutine */ int odlsvl_(integer *idx, logical *lpara)
{
    return odlqnp_0_(5, (integer *)0, (char *)0, idx, lpara, (integer *)0, (
	    ftnint)0);
    }

/* Subroutine */ int odlqin_(char *cp, integer *in, ftnlen cp_len)
{
    return odlqnp_0_(6, (integer *)0, cp, (integer *)0, (logical *)0, in, 
	    cp_len);
    }
